==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/LegendMouseButtonEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendMouseButtonEventArgsDescription } from "./LegendMouseButtonEventArgsDescription";
/**
 * @hidden
 */
var LegendMouseButtonEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LegendMouseButtonEventArgsDescriptionMetadata, _super);
    function LegendMouseButtonEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LegendMouseButtonEventArgsDescriptionMetadata.b = function (a) {
        if (LegendMouseButtonEventArgsDescriptionMetadata.a == null) {
            LegendMouseButtonEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LegendMouseButtonEventArgsDescriptionMetadata.c(LegendMouseButtonEventArgsDescriptionMetadata.a);
        }
        if (a.g(LegendMouseButtonEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(LegendMouseButtonEventArgsDescriptionMetadata.a);
    };
    LegendMouseButtonEventArgsDescriptionMetadata.c = function (a) {
        a.item("Handled", "Boolean");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        a.item("LegendItemRef", "(w:LegendItem,wf:LegendItem)DataRef");
    };
    LegendMouseButtonEventArgsDescriptionMetadata.d = function (a) {
        LegendMouseButtonEventArgsDescriptionMetadata.b(a);
        a.u("LegendMouseButtonEventArgs", function () { return new LegendMouseButtonEventArgsDescription(); });
        a.t("LegendMouseButtonEventArgs", LegendMouseButtonEventArgsDescriptionMetadata.a);
    };
    LegendMouseButtonEventArgsDescriptionMetadata.$t = markType(LegendMouseButtonEventArgsDescriptionMetadata, 'LegendMouseButtonEventArgsDescriptionMetadata');
    LegendMouseButtonEventArgsDescriptionMetadata.a = null;
    return LegendMouseButtonEventArgsDescriptionMetadata;
}(Base));
export { LegendMouseButtonEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/LegendMouseButtonEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendMouseButtonEventArgsDescription } from "./LegendMouseButtonEventArgsDescription";
/**
 * @hidden
 */
var LegendMouseButtonEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LegendMouseButtonEventArgsDescriptionMetadata, _super);
    function LegendMouseButtonEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LegendMouseButtonEventArgsDescriptionMetadata.b = function (a) {
        if (LegendMouseButtonEventArgsDescriptionMetadata.a == null) {
            LegendMouseButtonEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LegendMouseButtonEventArgsDescriptionMetadata.c(LegendMouseButtonEventArgsDescriptionMetadata.a);
        }
        if (a.j(LegendMouseButtonEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(LegendMouseButtonEventArgsDescriptionMetadata.a);
    };
    LegendMouseButtonEventArgsDescriptionMetadata.c = function (a) {
        a.item("Handled", "Boolean");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        a.item("LegendItemRef", "(w:LegendItem,wf:LegendItem)DataRef");
    };
    LegendMouseButtonEventArgsDescriptionMetadata.d = function (a) {
        LegendMouseButtonEventArgsDescriptionMetadata.b(a);
        a.aa("LegendMouseButtonEventArgs", function () { return new LegendMouseButtonEventArgsDescription(); });
        a.z("LegendMouseButtonEventArgs", LegendMouseButtonEventArgsDescriptionMetadata.a);
    };
    LegendMouseButtonEventArgsDescriptionMetadata.$t = markType(LegendMouseButtonEventArgsDescriptionMetadata, 'LegendMouseButtonEventArgsDescriptionMetadata');
    LegendMouseButtonEventArgsDescriptionMetadata.a = null;
    return LegendMouseButtonEventArgsDescriptionMetadata;
}(Base));
export { LegendMouseButtonEventArgsDescriptionMetadata };
